-- =============================================
-- Application: Sample 03 - Budgeting Example
-- Version 10.13, April 29, 2024
--
-- Copyright 2019-2024 Gartle LLC
--
-- License: MIT
--
-- Prerequisites: SaveToDB Framework 8.19 or higher
-- =============================================

SET NOCOUNT ON
GO

CREATE SCHEMA s03;
GO

CREATE TABLE [s03].[dimensions] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(50) NOT NULL
    , CONSTRAINT [PK_dimensions] PRIMARY KEY ([id])
    , CONSTRAINT [IX_dimensions_code] UNIQUE ([code])
    , CONSTRAINT [IX_dimensions_name] UNIQUE ([name])
);
GO

CREATE TABLE [s03].[members] (
      [id] int IDENTITY(1,1) NOT NULL
    , [dimension_id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , CONSTRAINT [PK_members] PRIMARY KEY ([id])
    , CONSTRAINT [IX_members_code] UNIQUE ([code])
    , CONSTRAINT [IX_members_name] UNIQUE ([name])
);
GO

ALTER TABLE [s03].[members] ADD CONSTRAINT [FK_members_dimensions] FOREIGN KEY ([dimension_id]) REFERENCES [s03].[dimensions] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [s03].[reports] (
      [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [row_index] int NOT NULL
    , [row_id] int NULL
    , [report] int NULL
    , [row_level] int NULL
    , [row_format] int NULL
    , [zero] int NULL
    , [hide] int NULL
    , [section] nvarchar(50) NULL
    , [account] nvarchar(50) NULL
    , [code1] nvarchar(50) NULL
    , [code2] nvarchar(50) NULL
    , [data_key] nvarchar(100) NULL
    , [data_index] int NULL
    , [code] nvarchar(50) NULL
    , [name] nvarchar(255) NULL
    , [data00] float NULL
    , [data01] float NULL
    , [data02] float NULL
    , [data03] float NULL
    , [data04] float NULL
    , [data05] float NULL
    , [data06] float NULL
    , [data07] float NULL
    , [data08] float NULL
    , [data09] float NULL
    , [data10] float NULL
    , [data11] float NULL
    , [data12] float NULL
    , [transaction_start_time] datetime NULL
    , CONSTRAINT [PK_budget_reports] PRIMARY KEY ([category_id], [time_id], [row_index])
);
GO

ALTER TABLE [s03].[reports] ADD CONSTRAINT [FK_reports_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [s03].[members] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s03].[reports] ADD CONSTRAINT [FK_reports_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [s03].[members] ([id]);
GO

CREATE TABLE [s03].[requests] (
      [id] int IDENTITY(1,1) NOT NULL
    , [entity_id] int NOT NULL
    , [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [row_index] int NOT NULL
    , [row_format] int NULL
    , [comment] nvarchar(255) NULL
    , [account_id] int NULL
    , [subaccount_id] int NULL
    , [product_id] int NULL
    , [region_id] int NULL
    , [total] float NULL
    , [01] float NULL
    , [02] float NULL
    , [03] float NULL
    , [04] float NULL
    , [05] float NULL
    , [06] float NULL
    , [07] float NULL
    , [08] float NULL
    , [09] float NULL
    , [10] float NULL
    , [11] float NULL
    , [12] float NULL
    , [row_formulas] nvarchar(max) NULL
    , [row_comments] nvarchar(max) NULL
    , [transaction_start_time] datetime NULL
    , [is_empty] AS (CONVERT([bit],case when [comment] IS NOT NULL OR [account_id] IS NOT NULL OR [subaccount_id] IS NOT NULL OR [product_id] IS NOT NULL OR [01] IS NOT NULL OR [02] IS NOT NULL OR [03] IS NOT NULL OR [04] IS NOT NULL OR [05] IS NOT NULL OR [06] IS NOT NULL OR [07] IS NOT NULL OR [08] IS NOT NULL OR [09] IS NOT NULL OR [10] IS NOT NULL OR [11] IS NOT NULL OR [12] IS NOT NULL then (0) else (1) end))
    , CONSTRAINT [PK_requests] PRIMARY KEY ([id])
    , CONSTRAINT [IX_requests] UNIQUE ([category_id], [time_id], [entity_id], [row_index])
);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_account_id] FOREIGN KEY ([account_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_entity_id] FOREIGN KEY ([entity_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_product_id] FOREIGN KEY ([product_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_region_id] FOREIGN KEY ([region_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_subaccount_id] FOREIGN KEY ([subaccount_id]) REFERENCES [s03].[members] ([id]);
GO

ALTER TABLE [s03].[requests] ADD CONSTRAINT [FK_requests_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [s03].[members] ([id]);
GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects aggregate data from s03.requests
-- =============================================

CREATE PROCEDURE [s03].[usp_data]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.section + '.' + m3.code + COALESCE('.' + m4.code, '') + COALESCE('.' + m5.code, '') + COALESCE('.' + m6.code, '') + COALESCE('.' + m7.code, '') AS code
    , t.section
    , m1.code AS category
    , m2.code AS [time]
    , m3.code AS account
    , m3.name AS account_name
    , m4.code AS entity
    , m4.name AS entity_name
    , m5.code AS region
    , m5.name AS region_name
    , m6.code AS product
    , m6.name AS product_name
    , m7.code AS subaccount
    , m7.name AS subaccount_name
    , COALESCE([01], 0) + COALESCE([02], 0) + COALESCE([03], 0) + COALESCE([04], 0) + COALESCE([05], 0) + COALESCE([06], 0) + COALESCE([07], 0) + COALESCE([08], 0) + COALESCE([09], 0) + COALESCE([10], 0) + COALESCE([11], 0) + COALESCE([12], 0) AS total
    , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
FROM
    (
        SELECT
            'accounts' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
        HAVING
            account_id IS NOT NULL
        UNION ALL
        SELECT
            'entities' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , t.entity_id
            , NULL AS product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.entity_id
        HAVING
            entity_id IS NOT NULL
        UNION ALL
        SELECT
            'regions' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , t.region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.region_id
        HAVING
            region_id IS NOT NULL
        UNION ALL
        SELECT
            'products' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , t.product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.product_id
        HAVING
            product_id IS NOT NULL
        UNION ALL
        SELECT
            'region_products' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , t.product_id
            , t.region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.region_id
            , t.product_id
        HAVING
            region_id IS NOT NULL
            AND product_id IS NOT NULL
        UNION ALL
        SELECT
            'subaccounts' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , NULL AS region_id
            , t.subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s03.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.subaccount_id
        HAVING
            subaccount_id IS NOT NULL
    ) t
    INNER JOIN s03.members m1 ON m1.id = t.category_id
    INNER JOIN s03.members m2 ON m2.id = t.time_id
    INNER JOIN s03.members m3 ON m3.id = t.account_id
    LEFT OUTER JOIN s03.members m4 ON m4.id = t.entity_id
    LEFT OUTER JOIN s03.members m5 ON m5.id = t.region_id
    LEFT OUTER JOIN s03.members m6 ON m6.id = t.product_id
    LEFT OUTER JOIN s03.members m7 ON m7.id = t.subaccount_id
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects data from s03.budget_reports
-- =============================================

CREATE PROCEDURE [s03].[usp_report]
    @category_id int = NULL
    , @time_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.row_index
    , t.row_id
    , t.report
    , t.row_level
    , t.row_format
    , t.zero
    , t.hide
    , t.section
    , t.account
    , t.code1
    , t.code2
    , t.data_key
    , t.data_index
    , t.code
    , t.name
    , t.data00
    , t.data01
    , t.data02
    , t.data03
    , t.data04
    , t.data05
    , t.data06
    , t.data07
    , t.data08
    , t.data09
    , t.data10
    , t.data11
    , t.data12
FROM
    s03.reports t
WHERE
    t.category_id = @category_id
    AND t.time_id = @time_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure deleted data from s03.budget_reports
-- =============================================

CREATE PROCEDURE [s03].[usp_report_delete]
    @category_id int
    , @time_id int
    , @row_index int
AS
BEGIN

DELETE FROM s03.reports
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND row_index = @row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure inserts data into s03.reports
-- =============================================

CREATE PROCEDURE [s03].[usp_report_insert]
    @category_id int
    , @time_id int
    , @row_index int
    , @rownum int
    , @row_id int = NULL
    , @report int = NULL
    , @row_level int = NULL
    , @row_format int = NULL
    , @zero int = NULL
    , @hide int = NULL
    , @section nvarchar(50) = NULL
    , @account nvarchar(50) = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @data_key nvarchar(100) = NULL
    , @data_index int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(255) = NULL
    , @data00 float = NULL
    , @data01 float = NULL
    , @data02 float = NULL
    , @data03 float = NULL
    , @data04 float = NULL
    , @data05 float = NULL
    , @data06 float = NULL
    , @data07 float = NULL
    , @data08 float = NULL
    , @data09 float = NULL
    , @data10 float = NULL
    , @data11 float = NULL
    , @data12 float = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

INSERT INTO s03.reports
    ( category_id
    , time_id
    , row_index
    , row_id
    , report
    , row_level
    , row_format
    , zero
    , hide
    , section
    , account
    , code1
    , code2
    , data_key
    , data_index
    , code
    , name
    , data00
    , data01
    , data02
    , data03
    , data04
    , data05
    , data06
    , data07
    , data08
    , data09
    , data10
    , data11
    , data12
    , transaction_start_time
    )
VALUES
    ( @category_id
    , @time_id
    , @rownum
    , @row_id
    , @report
    , @row_level
    , @row_format
    , @zero
    , @hide
    , @section
    , @account
    , @code1
    , @code2
    , @data_key
    , @data_index
    , @code
    , @name
    , @data00
    , @data01
    , @data02
    , @data03
    , @data04
    , @data05
    , @data06
    , @data07
    , @data08
    , @data09
    , @data10
    , @data11
    , @data12
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure updates data of s03.reports
-- =============================================

CREATE PROCEDURE [s03].[usp_report_update]
    @category_id int
    , @time_id int
    , @row_index int
    , @rownum int
    , @row_id int = NULL
    , @report int = NULL
    , @row_level int = NULL
    , @row_format int = NULL
    , @zero int = NULL
    , @hide int = NULL
    , @section nvarchar(50) = NULL
    , @account nvarchar(50) = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @data_key nvarchar(100) = NULL
    , @data_index int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(255) = NULL
    , @data00 float = NULL
    , @data01 float = NULL
    , @data02 float = NULL
    , @data03 float = NULL
    , @data04 float = NULL
    , @data05 float = NULL
    , @data06 float = NULL
    , @data07 float = NULL
    , @data08 float = NULL
    , @data09 float = NULL
    , @data10 float = NULL
    , @data11 float = NULL
    , @data12 float = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

UPDATE s03.reports
SET
    row_index = @rownum
    , row_id = @row_id
    , report = @report
    , row_level = @row_level
    , row_format = @row_format
    , zero = @zero
    , hide = @hide
    , section = @section
    , account = @account
    , code1 = @code1
    , code2 = @code2
    , data_key = @data_key
    , data_index = @data_index
    , code = @code
    , name = @name
    , data00 = @data00
    , data01 = @data01
    , data02 = @data02
    , data03 = @data03
    , data04 = @data04
    , data05 = @data05
    , data06 = @data06
    , data07 = @data07
    , data08 = @data08
    , data09 = @data09
    , data10 = @data10
    , data11 = @data11
    , data12 = @data12
    , transaction_start_time = @transaction_start_time
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND row_index = @row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects data from s03.requests
-- =============================================

CREATE PROCEDURE [s03].[usp_request]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rows int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @rows IS NULL SET @rows = 5

DECLARE @row_count int = COALESCE((
    SELECT
        MAX(t.row_index) AS row_index
    FROM
        s03.requests t
    WHERE
        t.entity_id = @entity_id
        AND t.category_id = @category_id
        AND t.time_id = @time_id
        AND t.is_empty = 0
    ), 0)

IF @row_count < @rows SET @row_count = @rows

;WITH e1(n) AS
(
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1
),                                              -- 10
e2(n) AS (SELECT 1 FROM e1 CROSS JOIN e1 AS b), -- 10*10
e3(n) AS (SELECT 1 FROM e1 CROSS JOIN e2)       -- 10*100

SELECT
    n.row_index
    , t.row_format
    , t.comment
    , t.account_id
    , t.subaccount_id
    , t.product_id
    , t.region_id
    , '=[@01]+[@02]+[@03]+[@04]+[@05]+[@06]+[@07]+[@08]+[@09]+[@10]+[@11]+[@12]' AS total
    , t.[01]
    , t.[02]
    , t.[03]
    , t.[04]
    , t.[05]
    , t.[06]
    , t.[07]
    , t.[08]
    , t.[09]
    , t.[10]
    , t.[11]
    , t.[12]
    , t.row_formulas
    , t.row_comments
FROM
    (SELECT ROW_NUMBER() OVER (ORDER BY n) AS row_index FROM e3) n
    LEFT OUTER JOIN s03.requests t ON
        t.row_index = n.row_index
        AND t.entity_id = @entity_id
        AND t.category_id = @category_id
        AND t.time_id = @time_id
WHERE
    n.row_index BETWEEN 1 AND @row_count
ORDER BY
    n.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure deleted data from s03.requests
-- =============================================

CREATE PROCEDURE [s03].[usp_request_delete]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

DELETE FROM s03.requests
WHERE
    entity_id = @entity_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @rownum
    AND transaction_start_time <= @transaction_start_time

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure updates data of s03.requests
-- =============================================

CREATE PROCEDURE [s03].[usp_request_update]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @comment nvarchar(255) = NULL
    , @account_id int = NULL
    , @subaccount_id int = NULL
    , @product_id int = NULL
    , @region_id int = NULL
    , @total float = NULL
    , @01 float = NULL, @02 float = NULL, @03 float = NULL, @04 float = NULL, @05 float = NULL, @06 float = NULL, @07 float = NULL, @08 float = NULL, @09 float = NULL, @10 float = NULL, @11 float = NULL, @12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
    , @is_insert bit = NULL
AS
BEGIN

UPDATE s03.requests
SET
    @row_index = @rownum
    , row_format = @row_format
    , comment = @comment
    , account_id = @account_id
    , subaccount_id = @subaccount_id
    , product_id = @product_id
    , region_id = @region_id
    , total = COALESCE(@01, 0) + COALESCE(@02, 0) + COALESCE(@03, 0) + COALESCE(@04, 0) + COALESCE(@05, 0) + COALESCE(@06, 0) + COALESCE(@07, 0) + COALESCE(@08, 0) + COALESCE(@09, 0) + COALESCE(@10, 0) + COALESCE(@11, 0) + COALESCE(@12, 0)
    , [01] = @01, [02] = @02, [03] = @03, [04] = @04, [05] = @05, [06] = @06, [07] = @07, [08] = @08, [09] = @09, [10] = @10, [11] = @11, [12] = @12
    , row_formulas = @row_formulas
    , row_comments = @row_comments
    , transaction_start_time = @transaction_start_time
WHERE
    entity_id = @entity_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @rownum

IF @@ROWCOUNT = 0
    IF COALESCE(@is_insert, 0) = 1
        OR @comment IS NOT NULL
        OR @account_id IS NOT NULL
        OR @subaccount_id IS NOT NULL
        OR @product_id IS NOT NULL
        OR @region_id IS NOT NULL
        OR @01 IS NOT NULL OR @02 IS NOT NULL OR @03 IS NOT NULL OR @04 IS NOT NULL OR @05 IS NOT NULL OR @06 IS NOT NULL OR @07 IS NOT NULL OR @08 IS NOT NULL OR @09 IS NOT NULL OR @10 IS NOT NULL OR @11 IS NOT NULL OR @12 IS NOT NULL
INSERT INTO s03.requests
    ( entity_id
    , category_id
    , time_id
    , row_index
    , row_format
    , comment
    , account_id
    , subaccount_id
    , product_id
    , region_id
    , total
    , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
    , row_formulas
    , row_comments
    , transaction_start_time
    )
VALUES
    ( @entity_id
    , @category_id
    , @time_id
    , @rownum
    , @row_format
    , @comment
    , @account_id
    , @subaccount_id
    , @product_id
    , @region_id
    , COALESCE(@01, 0) + COALESCE(@02, 0) + COALESCE(@03, 0) + COALESCE(@04, 0) + COALESCE(@05, 0) + COALESCE(@06, 0) + COALESCE(@07, 0) + COALESCE(@08, 0) + COALESCE(@09, 0) + COALESCE(@10, 0) + COALESCE(@11, 0) + COALESCE(@12, 0)
    , @01, @02, @03, @04, @05, @06, @07, @08, @09, @10, @11, @12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure inserts data into s03.requests
-- =============================================

CREATE PROCEDURE [s03].[usp_request_insert]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @comment nvarchar(255) = NULL
    , @account_id int = NULL
    , @subaccount_id int = NULL
    , @product_id int = NULL
    , @region_id int = NULL
    , @total float = NULL
    , @01 float = NULL, @02 float = NULL, @03 float = NULL, @04 float = NULL, @05 float = NULL, @06 float = NULL, @07 float = NULL, @08 float = NULL, @09 float = NULL, @10 float = NULL, @11 float = NULL, @12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

EXEC s03.usp_request_update
    @entity_id
    , @category_id
    , @time_id
    , @rownum
    , @row_index
    , @row_format
    , @comment
    , @account_id
    , @subaccount_id
    , @product_id
    , @region_id
    , @total
    , @01, @02, @03, @04, @05, @06, @07, @08, @09, @10, @11, @12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    , 1

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects all requests
-- =============================================

CREATE PROCEDURE [s03].[usp_requests]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    r.category_id
    , r.time_id
    , r.entity_id
    , MAX(m1.name) AS category
    , MAX(m2.name) AS [time]
    , MAX(m3.name) AS entity
    , MAX(r.transaction_start_time) AS last_update
FROM
    s03.requests r
    INNER JOIN s03.members m1 ON m1.id = r.category_id
    INNER JOIN s03.members m2 ON m2.id = r.time_id
    INNER JOIN s03.members m3 ON m3.id = r.entity_id
WHERE
    r.category_id = COALESCE(@category_id, r.category_id)
    AND r.time_id = COALESCE(@time_id, r.time_id)
    AND r.entity_id = COALESCE(@entity_id, r.entity_id)
GROUP BY
    r.category_id
    , r.time_id
    , r.entity_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure cleans the request data
-- =============================================

CREATE PROCEDURE [s03].[xl_actions_clean_requests]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @set_1_to_delete tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF NOT COALESCE(@set_1_to_delete, 0) = 1
    BEGIN
    SET @message = 'Set 1 in the parameter to delete data'
    RAISERROR (@message, 11, 0)
    RETURN
    END

DELETE FROM s03.requests
WHERE
    category_id = @category_id
    AND [time_id] = @time_id
    AND [entity_id] = COALESCE(@entity_id, [entity_id])

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure clones the request data
-- =============================================

CREATE PROCEDURE [s03].[xl_actions_clone_requests]
    @source_category_id int = NULL
    , @source_time_id int = NULL
    , @source_entity_id int = NULL
    , @target_category_id int = NULL
    , @target_time_id int = NULL
    , @target_entity_id int = NULL
    , @set_1_to_copy tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF NOT COALESCE(@set_1_to_copy, 0) = 1
    BEGIN
    SET @message = 'Set 1 in the parameter to copy data'
    RAISERROR (@message, 11, 0)
    RETURN
    END

BEGIN TRANSACTION

BEGIN TRY

    INSERT INTO s03.requests
        ( entity_id
        , category_id
        , time_id
        , row_index
        , row_format
        , comment
        , account_id
        , subaccount_id
        , product_id
        , region_id
        , total
        , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
        , row_formulas
        , transaction_start_time
        )
    SELECT
        COALESCE(@target_entity_id, f.entity_id)
        , @target_category_id
        , @target_time_id
        , row_index
        , row_format
        , comment
        , account_id
        , subaccount_id
        , product_id
        , region_id
        , total
        , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
        , row_formulas
        , transaction_start_time
    FROM
        s03.requests f
    WHERE
        f.category_id = @source_category_id
        AND f.time_id = @source_time_id
        AND f.entity_id = COALESCE(@source_entity_id, f.entity_id)

END TRY

BEGIN CATCH
    SELECT @message = ERROR_MESSAGE()

    IF @@TRANCOUNT > 0
        ROLLBACK TRANSACTION

    RAISERROR (@message, 11, 0, @message)
    RETURN

END CATCH

IF @@TRANCOUNT > 0
    COMMIT TRANSACTION

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects report cell data to an Excel window
-- =============================================

CREATE PROCEDURE [s03].[xl_details_report_cell_data]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @column_name nvarchar(128) = NULL
    , @account nvarchar(128) = NULL
    , @code1 nvarchar(128) = NULL
    , @code2 nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @entity_id = 0 SET @entity_id = NULL

DECLARE @id0 int, @id1 int, @id2 int

SELECT @id0 = id FROM s03.members WHERE code = @account
SELECT @id1 = id FROM s03.members WHERE code = @code1
SELECT @id2 = id FROM s03.members WHERE code = @code2

SELECT
    m4.code AS entity
    , t.comment
    , m1.code AS account
    , m7.name AS subaccount
    , m6.code AS product
    , m5.code AS region
    , t.total
    , t.[01]
    , t.[02]
    , t.[03]
    , t.[04]
    , t.[05]
    , t.[06]
    , t.[07]
    , t.[08]
    , t.[09]
    , t.[10]
    , t.[11]
    , t.[12]
FROM
    s03.requests t
    INNER JOIN s03.members m1 ON m1.id = t.account_id
    INNER JOIN s03.members m4 ON m4.id = t.[entity_id]
    LEFT OUTER JOIN s03.members m5 ON m5.id = t.region_id
    LEFT OUTER JOIN s03.members m6 ON m6.id = t.product_id
    LEFT OUTER JOIN s03.members m7 ON m7.id = t.subaccount_id
WHERE
    t.category_id = @category_id
    AND t.[time_id] = @time_id
    AND t.[entity_id] = COALESCE(@entity_id, t.[entity_id])
    AND t.account_id = @id0
    AND (COALESCE(t.region_id, 0) = COALESCE(@id1, t.region_id, 0)
        OR COALESCE(t.product_id, 0) = COALESCE(@id1, t.product_id, 0)
        OR COALESCE(t.subaccount_id, 0) = COALESCE(@id1, t.subaccount_id, 0)
        )
    AND (COALESCE(t.region_id, 0) = COALESCE(@id2, t.region_id, 0)
        OR COALESCE(t.product_id, 0) = COALESCE(@id2, t.product_id, 0)
        OR COALESCE(t.subaccount_id, 0) = COALESCE(@id2, t.subaccount_id, 0)
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: List of member_id
-- =============================================

CREATE PROCEDURE [s03].[xl_list_member_id]
    @dimension_id int = NULL
    , @name_format_id tinyint = NULL
AS
BEGIN

SELECT
    m.id
    , CASE @name_format_id
        WHEN 1 THEN m.name
        WHEN 2 THEN CAST(m.id AS nvarchar)
        WHEN 3 THEN CAST(m.id AS nvarchar) + ' ' + m.name
        WHEN 4 THEN m.code + ' ' + m.name
        ELSE m.code END AS name
FROM
    s03.members m
WHERE
    m.dimension_id = @dimension_id
ORDER BY
    name

END


GO

INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (1, N'accounts', N'Accounts');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (2, N'times', N'Times');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (3, N'categories', N'Categories');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (4, N'entities', N'Entities');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (5, N'regions', N'Regions');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (6, N'products', N'Products');
INSERT INTO [s03].[dimensions] ([id], [code], [name]) VALUES (7, N'subaccounts', N'Subaccounts');
GO

SET IDENTITY_INSERT [s03].[members] ON;
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (1, 3, N'BUDGET', N'Budget');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (2, 3, N'ACTUAL', N'Actual');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (3, 3, N'FORECAST', N'Forecast');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (4, 2, N'2023', N'2023');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (5, 2, N'2024', N'2024');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (6, 2, N'2025', N'2025');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (7, 1, N'100', N'Revenue');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (8, 1, N'200', N'Expenses');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (9, 1, N'300', N'Payroll');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (10, 1, N'400', N'Taxes');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (11, 4, N'E101', N'Entity 101');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (12, 4, N'E201', N'Entity 201');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (13, 4, N'E301', N'Entity 301');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (14, 4, N'E401', N'Entity 401');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (15, 5, N'US', N'USA');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (16, 5, N'CA', N'Canada');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (17, 5, N'UK', N'UK');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (18, 5, N'DE', N'Germany');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (19, 5, N'FR', N'France');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (20, 7, N'C01', N'Customer C1');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (21, 7, N'C02', N'Customer C2');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (22, 7, N'C03', N'Customer C3');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (23, 7, N'C04', N'Customer C4');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (24, 7, N'C05', N'Customer C5');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (25, 7, N'C06', N'Customer C6');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (26, 7, N'C07', N'Customer C7');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (27, 7, N'S01', N'Supplier S1');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (28, 7, N'S02', N'Supplier S2');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (29, 7, N'S03', N'Supplier S3');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (30, 7, N'S04', N'Supplier S4');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (31, 7, N'S05', N'Supplier S5');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (32, 7, N'S06', N'Supplier S6');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (33, 7, N'S07', N'Supplier S7');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (34, 7, N'T01', N'Corporate Income Tax');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (35, 7, N'T02', N'Individual Income Tax');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (36, 7, N'T03', N'Payroll Taxes');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (37, 6, N'P01', N'Product P1');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (38, 6, N'P02', N'Product P2');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (39, 6, N'P03', N'Product P3');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (40, 6, N'P04', N'Product P4');
INSERT INTO [s03].[members] ([id], [dimension_id], [code], [name]) VALUES (41, 6, N'P05', N'Product P5');
SET IDENTITY_INSERT [s03].[members] OFF;
GO

INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1512000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 3528000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, 294000, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 4, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:06:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 20400000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 7200000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 7200000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 20400000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 8400000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 20400000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 9300000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 9300000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 9300000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 11100000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 3900000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, 325000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 11100000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, 925000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 900000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, 75000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 20400000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, 1700000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 9300000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, 775000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 5580000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, 465000, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1674000, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 3906000, 325500, 325500, 325500, 325500, 325500, 325500, 325500, 325500, 325500, 325500, 325500, 325500, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 5, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:09:39.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 27600000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 9600000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 9600000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 8400000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, 700000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 27600000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 10800000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 27600000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 27600000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, 2300000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 7200000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 1080000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, 90000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1836000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 4284000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, 357000, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (1, 6, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:11:41.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 14520000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 14520000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 14520000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 8580000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 8580000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, 715000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 14520000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, 1210000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 5544000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, 462000, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1663200, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 3880800, 323400, 323400, 323400, 323400, 323400, 323400, 323400, 323400, 323400, 323400, 323400, 323400, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 4, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:12:33.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 22440000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 7920000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 7920000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 22440000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 9240000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, 770000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 22440000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 10080000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 3480000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 10080000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 10080000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 3480000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, 290000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 12360000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 4440000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 12360000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, 1030000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 1140000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, 95000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 22440000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, 1870000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 10080000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, 840000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 792000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, 66000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 6288000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, 524000, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1886400, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 4401600, 366800, 366800, 366800, 366800, 366800, 366800, 366800, 366800, 366800, 366800, 366800, 366800, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (2, 5, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:15:34.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 3840000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 6240000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 2040000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 1440000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 2040000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, 170000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 1440000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, 120000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 4764000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, 397000, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1429200, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 3334800, 277900, 277900, 277900, 277900, 277900, 277900, 277900, 277900, 277900, 277900, 277900, 277900, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 4, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:27:32.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 21120000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 7440000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 7440000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 6240000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, 520000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 21120000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 8640000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 21120000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 9900000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 3420000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 3840000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 9900000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 3840000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, 320000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 9900000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 3420000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, 285000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 11220000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 4020000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, 335000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 11220000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, 935000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 1020000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, 85000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 21120000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, 1760000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 9900000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, 825000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 756000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, 63000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 5424000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, 452000, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1627200, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 3796800, 316400, 316400, 316400, 316400, 316400, 316400, 316400, 316400, 316400, 316400, 316400, 316400, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 5, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:32:06.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 1, 10000, 1, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 2, 10010, 1, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Revenue', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 3, 10020, 1, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 4, 10030, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 5, 10040, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Products', 28320000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 6, 10050, 1, 2, 0, 0, 1, N'products', N'100', N'P01', NULL, N'products.100.P01', 12, N'P01', N'Product P1', 9840000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 7, 10060, 1, 2, 0, 0, 1, N'products', N'100', N'P02', NULL, N'products.100.P02', 13, N'P02', N'Product P2', 9840000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, 820000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 8, 10070, 1, 2, 0, 0, 1, N'products', N'100', N'P03', NULL, N'products.100.P03', 14, N'P03', N'Product P3', 8640000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, 720000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 9, 10080, 1, 2, 0, 1, 0, N'products', N'100', N'P04', NULL, N'products.100.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 10, 10090, 1, 2, 0, 1, 0, N'products', N'100', N'P05', NULL, N'products.100.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 11, 10100, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 12, 10110, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Regions', 28320000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 13, 10120, 1, 2, 0, 0, 1, N'regions', N'100', N'US', NULL, N'regions.100.US', 34, N'US', N'USA', 11040000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, 920000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 14, 10130, 1, 2, 0, 0, 1, N'regions', N'100', N'CA', NULL, N'regions.100.CA', 30, N'CA', N'Canada', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 15, 10140, 1, 2, 0, 0, 1, N'regions', N'100', N'UK', NULL, N'regions.100.UK', 33, N'UK', N'UK', 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 16, 10150, 1, 2, 0, 0, 1, N'regions', N'100', N'DE', NULL, N'regions.100.DE', 31, N'DE', N'Germany', 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 17, 10160, 1, 2, 0, 0, 1, N'regions', N'100', N'FR', NULL, N'regions.100.FR', 32, N'FR', N'France', 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 18, 10170, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 19, 10180, 1, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, NULL, N'All Customers', 28320000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 20, 10190, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C01', NULL, N'subaccounts.100.C01', 44, N'C01', N'Customer C1', 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 21, 10200, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C02', NULL, N'subaccounts.100.C02', 45, N'C02', N'Customer C2', 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 22, 10210, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C03', NULL, N'subaccounts.100.C03', 46, N'C03', N'Customer C3', 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 23, 10220, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C04', NULL, N'subaccounts.100.C04', 47, N'C04', N'Customer C4', 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 24, 10230, 1, 2, 0, 0, 1, N'subaccounts', N'100', N'C05', NULL, N'subaccounts.100.C05', 48, N'C05', N'Customer C5', 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 25, 10240, 1, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 26, 10250, 1, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 27, 20000, 2, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 28, 20010, 2, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Expenses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 29, 20020, 2, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 30, 20030, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 31, 20040, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Products', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 32, 20050, 2, 2, 0, 0, 1, N'products', N'200', N'P01', NULL, N'products.200.P01', 15, N'P01', N'Product P1', 4440000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 33, 20060, 2, 2, 0, 0, 1, N'products', N'200', N'P02', NULL, N'products.200.P02', 16, N'P02', N'Product P2', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 34, 20070, 2, 2, 0, 0, 1, N'products', N'200', N'P03', NULL, N'products.200.P03', 17, N'P03', N'Product P3', 4440000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 35, 20080, 2, 2, 0, 1, 0, N'products', N'200', N'P04', NULL, N'products.200.P04', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 36, 20090, 2, 2, 0, 1, 0, N'products', N'200', N'P05', NULL, N'products.200.P05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 37, 20100, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 38, 20110, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Regions', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 39, 20120, 2, 2, 0, 0, 1, N'regions', N'200', N'US', NULL, N'regions.200.US', 39, N'US', N'USA', 5040000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, 420000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 40, 20130, 2, 2, 0, 0, 1, N'regions', N'200', N'CA', NULL, N'regions.200.CA', 35, N'CA', N'Canada', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 41, 20140, 2, 2, 0, 0, 1, N'regions', N'200', N'UK', NULL, N'regions.200.UK', 38, N'UK', N'UK', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 42, 20150, 2, 2, 0, 0, 1, N'regions', N'200', N'DE', NULL, N'regions.200.DE', 36, N'DE', N'Germany', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 43, 20160, 2, 2, 0, 0, 1, N'regions', N'200', N'FR', NULL, N'regions.200.FR', 37, N'FR', N'France', 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 44, 20170, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 45, 20180, 2, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, NULL, N'All Suppliers', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 46, 20190, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S01', NULL, N'subaccounts.200.S01', 50, N'S01', N'Supplier S1', 4440000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 47, 20200, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S02', NULL, N'subaccounts.200.S02', 51, N'S02', N'Supplier S2', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 48, 20210, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S03', NULL, N'subaccounts.200.S03', 52, N'S03', N'Supplier S3', 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 49, 20220, 2, 2, 0, 0, 1, N'subaccounts', N'200', N'S04', NULL, N'subaccounts.200.S04', 53, N'S04', N'Supplier S4', 4440000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, 370000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 50, 20230, 2, 2, 0, 1, 0, N'subaccounts', N'200', N'S05', NULL, N'subaccounts.200.S05', 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 51, 20240, 2, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 52, 20250, 2, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 53, 30000, 3, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 54, 30010, 3, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Margin Profit', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 55, 30020, 3, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 56, 30030, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 57, 30040, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Products', 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 58, 30050, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P01', N'Product P1', 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 59, 30060, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P02', N'Product P2', 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 60, 30070, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'P03', N'Product P3', 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 61, 30080, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 62, 30090, 3, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 63, 30100, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 64, 30110, 3, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'By Regions', 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 65, 30120, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'US', N'USA', 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 66, 30130, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'CA', N'Canada', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 67, 30140, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'UK', N'UK', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 68, 30150, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'DE', N'Germany', 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 69, 30160, 3, 2, 0, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, N'FR', N'France', 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 70, 30170, 3, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 71, 40000, 4, -3, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 72, 40010, 4, -2, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Profit & Losses', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 73, 40020, 4, -1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, N'Code', N'Name', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 74, 40030, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 75, 40040, 4, 1, 1, 0, 1, N'accounts', N'100', NULL, NULL, N'accounts.100', 1, N'100', N'Revenue', 28320000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, 2360000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 76, 40050, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 77, 40060, 4, 1, 1, 0, 1, N'accounts', N'200', NULL, NULL, N'accounts.200', 2, N'200', N'Expenses', 13920000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, 1160000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 78, 40070, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 79, 40080, 4, 1, 1, 0, 1, N'accounts', N'300', NULL, NULL, N'accounts.300', 3, N'300', N'Payroll', 7440000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, 620000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 80, 40090, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T03', NULL, N'subaccounts.400.T03', 56, N'T03', N'Payroll Taxes', 1116000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, 93000, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 81, 40100, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 82, 40110, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Pre-Tax Income', 5844000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, 487000, '20210807 16:37:30.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 83, 40120, 4, 2, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 84, 40130, 4, 2, 0, 0, 1, N'subaccounts', N'400', N'T01', NULL, N'subaccounts.400.T01', 54, N'T01', N'Corporate Income Tax', 1753200, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, '20210807 16:37:38.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 85, 40140, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 86, 40150, 4, 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, N'Net Income', 4090800, 340900, 340900, 340900, 340900, 340900, 340900, 340900, 340900, 340900, 340900, 340900, 340900, '20210807 16:37:38.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 87, 40160, 4, 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 88, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
INSERT INTO [s03].[reports] ([category_id], [time_id], [row_index], [row_id], [report], [row_level], [row_format], [zero], [hide], [section], [account], [code1], [code2], [data_key], [data_index], [code], [name], [data00], [data01], [data02], [data03], [data04], [data05], [data06], [data07], [data08], [data09], [data10], [data11], [data12], [transaction_start_time]) VALUES (3, 6, 89, NULL, 0, 4, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 16:35:12.000');
GO

SET IDENTITY_INSERT [s03].[requests] ON;
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (1, 11, 1, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 10800000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:40:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (2, 11, 1, 5, 3, NULL, NULL, 7, 20, 37, 15, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:40:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (3, 11, 1, 5, 4, NULL, NULL, 7, 21, 38, 15, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:40:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (4, 11, 1, 5, 5, NULL, NULL, 7, 22, 37, 16, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:40:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (5, 12, 1, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 9600000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:51:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (6, 12, 1, 5, 3, NULL, NULL, 7, 23, 38, 17, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:51:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (7, 12, 1, 5, 4, NULL, NULL, 7, 24, 39, 18, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:51:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (8, 12, 1, 5, 5, NULL, NULL, 7, 25, 39, 19, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:51:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (9, 12, 1, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:07:56.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (10, 12, 1, 5, 8, NULL, NULL, 8, 29, 38, 17, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:56.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (11, 12, 1, 5, 9, NULL, NULL, 8, 30, 39, 18, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:56.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (12, 12, 1, 5, 10, NULL, NULL, 8, 30, 39, 19, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:56.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (13, 12, 1, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:07:56.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (14, 11, 1, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5100000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:07:39.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (15, 11, 1, 5, 8, NULL, NULL, 8, 27, 37, 15, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:39.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (16, 11, 1, 5, 9, NULL, NULL, 8, 28, 38, 15, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:39.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (17, 11, 1, 5, 10, NULL, NULL, 8, 27, 37, 16, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:07:39.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (18, 11, 1, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5700000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:07:39.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (19, 13, 1, 5, 2, 1, NULL, 9, NULL, NULL, 15, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (20, 13, 1, 5, 4, NULL, NULL, 10, 36, NULL, 15, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (21, 13, 1, 5, 8, NULL, NULL, 10, 36, NULL, 17, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (22, 13, 1, 5, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (23, 13, 1, 5, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (24, 13, 1, 5, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (25, 13, 1, 5, 3, NULL, NULL, 10, 35, NULL, 15, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (26, 13, 1, 5, 6, 1, NULL, 9, NULL, NULL, 17, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (27, 13, 1, 5, 7, NULL, NULL, 10, 35, NULL, 17, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:55:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (28, 14, 1, 5, 2, 1, NULL, 10, 34, NULL, NULL, 1674000, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, NULL, NULL, '20210807 16:09:26.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (29, 11, 1, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7200000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (30, 11, 1, 4, 3, NULL, NULL, 7, 20, 37, 15, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (31, 11, 1, 4, 4, NULL, NULL, 7, 21, 38, 15, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (32, 11, 1, 4, 5, NULL, NULL, 7, 22, 37, 16, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (33, 12, 1, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (34, 12, 1, 4, 3, NULL, NULL, 7, 23, 38, 17, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (35, 12, 1, 4, 4, NULL, NULL, 7, 24, 39, 18, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (36, 12, 1, 4, 5, NULL, NULL, 7, 25, 39, 19, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (37, 12, 1, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (38, 12, 1, 4, 8, NULL, NULL, 8, 29, 38, 17, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (39, 12, 1, 4, 9, NULL, NULL, 8, 30, 39, 18, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (40, 12, 1, 4, 10, NULL, NULL, 8, 30, 39, 19, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (41, 12, 1, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (42, 11, 1, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (43, 11, 1, 4, 8, NULL, NULL, 8, 27, 37, 15, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (44, 11, 1, 4, 9, NULL, NULL, 8, 28, 38, 15, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (45, 11, 1, 4, 10, NULL, NULL, 8, 27, 37, 16, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (46, 11, 1, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 15:45:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (47, 13, 1, 4, 2, 1, NULL, 9, NULL, NULL, 15, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (48, 13, 1, 4, 4, NULL, NULL, 10, 36, NULL, 15, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (49, 13, 1, 4, 8, NULL, NULL, 10, 36, NULL, 17, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (50, 13, 1, 4, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (51, 13, 1, 4, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (52, 13, 1, 4, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (53, 13, 1, 4, 3, NULL, NULL, 10, 35, NULL, 15, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (54, 13, 1, 4, 6, 1, NULL, 9, NULL, NULL, 17, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (55, 13, 1, 4, 7, NULL, NULL, 10, 35, NULL, 17, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (56, 14, 1, 4, 2, 1, NULL, 10, 34, NULL, NULL, 1512000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, NULL, NULL, '20210807 19:41:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (57, 11, 1, 6, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:42:51.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (58, 11, 1, 6, 3, NULL, NULL, 7, 20, 37, 15, 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:42:51.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (59, 11, 1, 6, 4, NULL, NULL, 7, 21, 38, 15, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:42:51.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (60, 11, 1, 6, 5, NULL, NULL, 7, 22, 37, 16, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:42:51.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (61, 12, 1, 6, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:52:31.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (62, 12, 1, 6, 3, NULL, NULL, 7, 23, 38, 17, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:52:31.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (63, 12, 1, 6, 4, NULL, NULL, 7, 24, 39, 18, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:52:31.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (64, 12, 1, 6, 5, NULL, NULL, 7, 25, 39, 19, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:52:31.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (65, 12, 1, 6, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:10:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (66, 12, 1, 6, 8, NULL, NULL, 8, 29, 38, 17, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (67, 12, 1, 6, 9, NULL, NULL, 8, 30, 39, 18, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (68, 12, 1, 6, 10, NULL, NULL, 8, 30, 39, 19, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (69, 12, 1, 6, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:10:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (70, 11, 1, 6, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:10:16.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (71, 11, 1, 6, 8, NULL, NULL, 8, 27, 37, 15, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:16.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (72, 11, 1, 6, 9, NULL, NULL, 8, 28, 38, 15, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:16.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (73, 11, 1, 6, 10, NULL, NULL, 8, 27, 37, 16, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:10:16.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (74, 11, 1, 6, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:10:16.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (75, 13, 1, 6, 2, 1, NULL, 9, NULL, NULL, 15, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (76, 13, 1, 6, 4, NULL, NULL, 10, 36, NULL, 15, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (77, 13, 1, 6, 8, NULL, NULL, 10, 36, NULL, 17, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (78, 13, 1, 6, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (79, 13, 1, 6, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (80, 13, 1, 6, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (81, 13, 1, 6, 3, NULL, NULL, 10, 35, NULL, 15, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (82, 13, 1, 6, 6, 1, NULL, 9, NULL, NULL, 17, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (83, 13, 1, 6, 7, NULL, NULL, 10, 35, NULL, 17, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:55:49.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (84, 14, 1, 6, 2, 1, NULL, 10, 34, NULL, NULL, 1836000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, NULL, NULL, '20210807 16:11:35.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (85, 11, 3, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7560000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (86, 11, 3, 4, 3, NULL, NULL, 7, 20, 37, 15, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (87, 11, 3, 4, 4, NULL, NULL, 7, 21, 38, 15, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (88, 11, 3, 4, 5, NULL, NULL, 7, 22, 37, 16, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (89, 12, 3, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6360000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (90, 12, 3, 4, 3, NULL, NULL, 7, 23, 38, 17, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (91, 12, 3, 4, 4, NULL, NULL, 7, 24, 39, 18, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (92, 12, 3, 4, 5, NULL, NULL, 7, 25, 39, 19, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (93, 12, 3, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2760000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (94, 12, 3, 4, 8, NULL, NULL, 8, 29, 38, 17, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (95, 12, 3, 4, 9, NULL, NULL, 8, 30, 39, 18, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (96, 12, 3, 4, 10, NULL, NULL, 8, 30, 39, 19, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:17.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (97, 12, 3, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (98, 11, 3, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3360000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (99, 11, 3, 4, 8, NULL, NULL, 8, 27, 37, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (100, 11, 3, 4, 9, NULL, NULL, 8, 28, 38, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (101, 11, 3, 4, 10, NULL, NULL, 8, 27, 37, 16, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:25:34.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (102, 11, 3, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (103, 13, 3, 4, 2, 1, NULL, 9, NULL, NULL, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (104, 13, 3, 4, 4, NULL, NULL, 10, 36, NULL, 15, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (105, 13, 3, 4, 8, NULL, NULL, 10, 36, NULL, 17, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (106, 13, 3, 4, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (107, 13, 3, 4, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (108, 13, 3, 4, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (109, 13, 3, 4, 3, NULL, NULL, 10, 35, NULL, 15, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (110, 13, 3, 4, 6, 1, NULL, 9, NULL, NULL, 17, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (111, 13, 3, 4, 7, NULL, NULL, 10, 35, NULL, 17, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:26:45.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (112, 14, 3, 4, 2, 1, NULL, 10, 34, NULL, NULL, 1429200, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, NULL, NULL, '20210807 16:27:23.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (113, 11, 3, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 11160000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (114, 11, 3, 5, 3, NULL, NULL, 7, 20, 37, 15, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (115, 11, 3, 5, 4, NULL, NULL, 7, 21, 38, 15, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (116, 11, 3, 5, 5, NULL, NULL, 7, 22, 37, 16, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (117, 12, 3, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 9960000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (118, 12, 3, 5, 3, NULL, NULL, 7, 23, 38, 17, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (119, 12, 3, 5, 4, NULL, NULL, 7, 24, 39, 18, 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (120, 12, 3, 5, 5, NULL, NULL, 7, 25, 39, 19, 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (121, 12, 3, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4560000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (122, 12, 3, 5, 8, NULL, NULL, 8, 29, 38, 17, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (123, 12, 3, 5, 9, NULL, NULL, 8, 30, 39, 18, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (124, 12, 3, 5, 10, NULL, NULL, 8, 30, 39, 19, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (125, 12, 3, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:30:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (126, 11, 3, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5340000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (127, 11, 3, 5, 8, NULL, NULL, 8, 27, 37, 15, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (128, 11, 3, 5, 9, NULL, NULL, 8, 28, 38, 15, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (129, 11, 3, 5, 10, NULL, NULL, 8, 27, 37, 16, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (130, 11, 3, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5820000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:29:42.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (131, 13, 3, 5, 2, 1, NULL, 9, NULL, NULL, 15, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (132, 13, 3, 5, 4, NULL, NULL, 10, 36, NULL, 15, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (133, 13, 3, 5, 8, NULL, NULL, 10, 36, NULL, 17, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (134, 13, 3, 5, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (135, 13, 3, 5, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (136, 13, 3, 5, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (137, 13, 3, 5, 3, NULL, NULL, 10, 35, NULL, 15, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (138, 13, 3, 5, 6, 1, NULL, 9, NULL, NULL, 17, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (139, 13, 3, 5, 7, NULL, NULL, 10, 35, NULL, 17, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:31:13.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (140, 14, 3, 5, 2, 1, NULL, 10, 34, NULL, NULL, 1627200, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, NULL, NULL, '20210807 16:31:53.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (141, 11, 3, 6, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 14760000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (142, 11, 3, 6, 3, NULL, NULL, 7, 20, 37, 15, 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (143, 11, 3, 6, 4, NULL, NULL, 7, 21, 38, 15, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (144, 11, 3, 6, 5, NULL, NULL, 7, 22, 37, 16, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (145, 12, 3, 6, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 13560000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (146, 12, 3, 6, 3, NULL, NULL, 7, 23, 38, 17, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (147, 12, 3, 6, 4, NULL, NULL, 7, 24, 39, 18, 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (148, 12, 3, 6, 5, NULL, NULL, 7, 25, 39, 19, 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (149, 12, 3, 6, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6960000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (150, 12, 3, 6, 8, NULL, NULL, 8, 29, 38, 17, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (151, 12, 3, 6, 9, NULL, NULL, 8, 30, 39, 18, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (152, 12, 3, 6, 10, NULL, NULL, 8, 30, 39, 19, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (153, 12, 3, 6, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:34:28.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (154, 11, 3, 6, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6960000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (155, 11, 3, 6, 8, NULL, NULL, 8, 27, 37, 15, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (156, 11, 3, 6, 9, NULL, NULL, 8, 28, 38, 15, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (157, 11, 3, 6, 10, NULL, NULL, 8, 27, 37, 16, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (158, 11, 3, 6, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:36:33.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (159, 13, 3, 6, 2, 1, NULL, 9, NULL, NULL, 15, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (160, 13, 3, 6, 4, NULL, NULL, 10, 36, NULL, 15, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (161, 13, 3, 6, 8, NULL, NULL, 10, 36, NULL, 17, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (162, 13, 3, 6, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (163, 13, 3, 6, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (164, 13, 3, 6, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (165, 13, 3, 6, 3, NULL, NULL, 10, 35, NULL, 15, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (166, 13, 3, 6, 6, 1, NULL, 9, NULL, NULL, 17, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (167, 13, 3, 6, 7, NULL, NULL, 10, 35, NULL, 17, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 16:34:48.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (168, 14, 3, 6, 2, 1, NULL, 10, 34, NULL, NULL, 1753200, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, NULL, NULL, '20210807 16:37:25.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (169, 11, 2, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7920000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (170, 11, 2, 4, 3, NULL, NULL, 7, 20, 37, 15, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (171, 11, 2, 4, 4, NULL, NULL, 7, 21, 38, 15, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (172, 11, 2, 4, 5, NULL, NULL, 7, 22, 37, 16, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (173, 12, 2, 4, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (174, 12, 2, 4, 3, NULL, NULL, 7, 23, 38, 17, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (175, 12, 2, 4, 4, NULL, NULL, 7, 24, 39, 18, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (176, 12, 2, 4, 5, NULL, NULL, 7, 25, 39, 19, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (177, 12, 2, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (178, 12, 2, 4, 8, NULL, NULL, 8, 29, 38, 17, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (179, 12, 2, 4, 9, NULL, NULL, 8, 30, 39, 18, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (180, 12, 2, 4, 10, NULL, NULL, 8, 30, 39, 19, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (181, 12, 2, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 15:53:20.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (182, 11, 2, 4, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (183, 11, 2, 4, 8, NULL, NULL, 8, 27, 37, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (184, 11, 2, 4, 9, NULL, NULL, 8, 28, 38, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (185, 11, 2, 4, 10, NULL, NULL, 8, 27, 37, 16, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (186, 11, 2, 4, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4620000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 15:49:43.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (187, 13, 2, 4, 2, 1, NULL, 9, NULL, NULL, 15, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (188, 13, 2, 4, 4, NULL, NULL, 10, 36, NULL, 15, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (189, 13, 2, 4, 8, NULL, NULL, 10, 36, NULL, 17, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (190, 13, 2, 4, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (191, 13, 2, 4, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (192, 13, 2, 4, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (193, 13, 2, 4, 3, NULL, NULL, 10, 35, NULL, 15, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (194, 13, 2, 4, 6, 1, NULL, 9, NULL, NULL, 17, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (195, 13, 2, 4, 7, NULL, NULL, 10, 35, NULL, 17, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:56:24.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (196, 14, 2, 4, 2, 1, NULL, 10, 34, NULL, NULL, 1663200, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, 138600, NULL, NULL, '20210807 16:12:26.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (197, 11, 2, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 11880000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (198, 11, 2, 5, 3, NULL, NULL, 7, 20, 37, 15, 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (199, 11, 2, 5, 4, NULL, NULL, 7, 21, 38, 15, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (200, 11, 2, 5, 5, NULL, NULL, 7, 22, 37, 16, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (201, 11, 2, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5460000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (202, 11, 2, 5, 8, NULL, NULL, 8, 27, 37, 15, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (203, 11, 2, 5, 9, NULL, NULL, 8, 28, 38, 15, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (204, 11, 2, 5, 10, NULL, NULL, 8, 27, 37, 16, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (205, 11, 2, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6420000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:13:02.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (206, 12, 2, 5, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 10560000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 15:54:03.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (207, 12, 2, 5, 3, NULL, NULL, 7, 23, 38, 17, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:54:03.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (208, 12, 2, 5, 4, NULL, NULL, 7, 24, 39, 18, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:54:03.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (209, 12, 2, 5, 5, NULL, NULL, 7, 25, 39, 19, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:54:03.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (210, 12, 2, 5, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4620000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 16:14:44.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (211, 12, 2, 5, 8, NULL, NULL, 8, 29, 38, 17, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:14:44.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (212, 12, 2, 5, 9, NULL, NULL, 8, 30, 39, 18, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:14:44.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (213, 12, 2, 5, 10, NULL, NULL, 8, 30, 39, 19, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 16:14:44.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (214, 12, 2, 5, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 16:14:44.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (215, 13, 2, 5, 2, 1, NULL, 9, NULL, NULL, 15, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (216, 13, 2, 5, 3, NULL, NULL, 10, 35, NULL, 15, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (217, 13, 2, 5, 4, NULL, NULL, 10, 36, NULL, 15, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (218, 13, 2, 5, 6, 1, NULL, 9, NULL, NULL, 17, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (219, 13, 2, 5, 7, NULL, NULL, 10, 35, NULL, 17, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (220, 13, 2, 5, 8, NULL, NULL, 10, 36, NULL, 17, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 15:56:54.000');
INSERT INTO [s03].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (221, 14, 2, 5, 2, 1, NULL, 10, 34, NULL, NULL, 1886400, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, NULL, NULL, '20210807 16:15:28.000');
SET IDENTITY_INSERT [s03].[requests] OFF;
GO

INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's03', N'members', N'<table name="s03.members"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="14.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="id" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's03', N'usp_data', N'<table name="s03.usp_data"><columnFormats><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$C$4" type="String" /><column name="code" property="ColumnWidth" value="25.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="Address" value="$D$4" type="String" /><column name="section" property="ColumnWidth" value="14.86" type="Double" /><column name="section" property="NumberFormat" value="General" type="String" /><column name="category" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category" property="Address" value="$E$4" type="String" /><column name="category" property="ColumnWidth" value="10.14" type="Double" /><column name="category" property="NumberFormat" value="General" type="String" /><column name="time" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="time" property="Address" value="$F$4" type="String" /><column name="time" property="ColumnWidth" value="6.71" type="Double" /><column name="time" property="NumberFormat" value="General" type="String" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="Address" value="$G$4" type="String" /><column name="account" property="ColumnWidth" value="9.43" type="Double" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="account_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="Address" value="$H$4" type="String" /><column name="account_name" property="ColumnWidth" value="15.57" type="Double" /><column name="account_name" property="NumberFormat" value="General" type="String" /><column name="entity" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity" property="Address" value="$I$4" type="String" /><column name="entity" property="ColumnWidth" value="7.86" type="Double" /><column name="entity" property="NumberFormat" value="General" type="String" /><column name="entity_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_name" property="Address" value="$J$4" type="String" /><column name="entity_name" property="ColumnWidth" value="13.86" type="Double" /><column name="entity_name" property="NumberFormat" value="General" type="String" /><column name="region" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region" property="Address" value="$K$4" type="String" /><column name="region" property="ColumnWidth" value="8.29" type="Double" /><column name="region" property="NumberFormat" value="General" type="String" /><column name="region_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_name" property="Address" value="$L$4" type="String" /><column name="region_name" property="ColumnWidth" value="14.29" type="Double" /><column name="region_name" property="NumberFormat" value="General" type="String" /><column name="product" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product" property="Address" value="$M$4" type="String" /><column name="product" property="ColumnWidth" value="9.43" type="Double" /><column name="product" property="NumberFormat" value="General" type="String" /><column name="product_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_name" property="Address" value="$N$4" type="String" /><column name="product_name" property="ColumnWidth" value="15.57" type="Double" /><column name="product_name" property="NumberFormat" value="General" type="String" /><column name="subaccount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount" property="Address" value="$O$4" type="String" /><column name="subaccount" property="ColumnWidth" value="12.57" type="Double" /><column name="subaccount" property="NumberFormat" value="General" type="String" /><column name="subaccount_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_name" property="Address" value="$P$4" type="String" /><column name="subaccount_name" property="ColumnWidth" value="18.86" type="Double" /><column name="subaccount_name" property="NumberFormat" value="General" type="String" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="Address" value="$Q$4" type="String" /><column name="total" property="ColumnWidth" value="9.14" type="Double" /><column name="total" property="NumberFormat" value="#,##0" type="String" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="Address" value="$R$4" type="String" /><column name="01" property="ColumnWidth" value="8.14" type="Double" /><column name="01" property="NumberFormat" value="#,##0" type="String" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="Address" value="$S$4" type="String" /><column name="02" property="ColumnWidth" value="8.14" type="Double" /><column name="02" property="NumberFormat" value="#,##0" type="String" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="Address" value="$T$4" type="String" /><column name="03" property="ColumnWidth" value="8.14" type="Double" /><column name="03" property="NumberFormat" value="#,##0" type="String" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="Address" value="$U$4" type="String" /><column name="04" property="ColumnWidth" value="8.14" type="Double" /><column name="04" property="NumberFormat" value="#,##0" type="String" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="Address" value="$V$4" type="String" /><column name="05" property="ColumnWidth" value="8.14" type="Double" /><column name="05" property="NumberFormat" value="#,##0" type="String" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="Address" value="$W$4" type="String" /><column name="06" property="ColumnWidth" value="8.14" type="Double" /><column name="06" property="NumberFormat" value="#,##0" type="String" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="Address" value="$X$4" type="String" /><column name="07" property="ColumnWidth" value="8.14" type="Double" /><column name="07" property="NumberFormat" value="#,##0" type="String" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="Address" value="$Y$4" type="String" /><column name="08" property="ColumnWidth" value="8.14" type="Double" /><column name="08" property="NumberFormat" value="#,##0" type="String" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="Address" value="$Z$4" type="String" /><column name="09" property="ColumnWidth" value="8.14" type="Double" /><column name="09" property="NumberFormat" value="#,##0" type="String" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="Address" value="$AA$4" type="String" /><column name="10" property="ColumnWidth" value="8.14" type="Double" /><column name="10" property="NumberFormat" value="#,##0" type="String" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="Address" value="$AB$4" type="String" /><column name="11" property="ColumnWidth" value="8.14" type="Double" /><column name="11" property="NumberFormat" value="#,##0" type="String" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="Address" value="$AC$4" type="String" /><column name="12" property="ColumnWidth" value="8.14" type="Double" /><column name="12" property="NumberFormat" value="#,##0" type="String" /><column name="" property="Tab.Color" value="5296274" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's03', N'usp_report', N'<table name="s03.usp_report"><columnFormats><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$4" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="row_index" property="Validation.Type" value="1" type="Double" /><column name="row_index" property="Validation.Operator" value="1" type="Double" /><column name="row_index" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_index" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_index" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_index" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_index" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_index" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="row_index" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="row_index" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_index" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="Address" value="$D$4" type="String" /><column name="row_id" property="NumberFormat" value="General" type="String" /><column name="row_id" property="Validation.Type" value="1" type="Double" /><column name="row_id" property="Validation.Operator" value="1" type="Double" /><column name="row_id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_id" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="row_id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="row_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="Address" value="$E$4" type="String" /><column name="report" property="NumberFormat" value="General" type="String" /><column name="report" property="Validation.Type" value="1" type="Double" /><column name="report" property="Validation.Operator" value="1" type="Double" /><column name="report" property="Validation.Formula1" value="-2147483648" type="String" /><column name="report" property="Validation.Formula2" value="2147483647" type="String" /><column name="report" property="Validation.AlertStyle" value="1" type="Double" /><column name="report" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="report" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="report" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="report" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="report" property="Validation.ShowInput" value="True" type="Boolean" /><column name="report" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="Address" value="$F$4" type="String" /><column name="row_level" property="NumberFormat" value="General" type="String" /><column name="row_level" property="Validation.Type" value="1" type="Double" /><column name="row_level" property="Validation.Operator" value="1" type="Double" /><column name="row_level" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_level" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_level" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_level" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_level" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_level" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="row_level" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="row_level" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_level" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$G$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="Validation.Type" value="1" type="Double" /><column name="row_format" property="Validation.Operator" value="1" type="Double" /><column name="row_format" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_format" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_format" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_format" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="row_format" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="row_format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowError" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="Address" value="$H$4" type="String" /><column name="zero" property="NumberFormat" value="General" type="String" /><column name="zero" property="Validation.Type" value="1" type="Double" /><column name="zero" property="Validation.Operator" value="1" type="Double" /><column name="zero" property="Validation.Formula1" value="-2147483648" type="String" /><column name="zero" property="Validation.Formula2" value="2147483647" type="String" /><column name="zero" property="Validation.AlertStyle" value="1" type="Double" /><column name="zero" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="zero" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="zero" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="zero" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="zero" property="Validation.ShowInput" value="True" type="Boolean" /><column name="zero" property="Validation.ShowError" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="Address" value="$I$4" type="String" /><column name="hide" property="NumberFormat" value="General" type="String" /><column name="hide" property="Validation.Type" value="1" type="Double" /><column name="hide" property="Validation.Operator" value="1" type="Double" /><column name="hide" property="Validation.Formula1" value="-2147483648" type="String" /><column name="hide" property="Validation.Formula2" value="2147483647" type="String" /><column name="hide" property="Validation.AlertStyle" value="1" type="Double" /><column name="hide" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="hide" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="hide" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="hide" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="hide" property="Validation.ShowInput" value="True" type="Boolean" /><column name="hide" property="Validation.ShowError" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="Address" value="$J$4" type="String" /><column name="section" property="NumberFormat" value="General" type="String" /><column name="section" property="Validation.Type" value="6" type="Double" /><column name="section" property="Validation.Operator" value="8" type="Double" /><column name="section" property="Validation.Formula1" value="50" type="String" /><column name="section" property="Validation.AlertStyle" value="1" type="Double" /><column name="section" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="section" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="section" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="section" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="section" property="Validation.ShowInput" value="True" type="Boolean" /><column name="section" property="Validation.ShowError" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="Address" value="$K$4" type="String" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="account" property="Validation.Type" value="6" type="Double" /><column name="account" property="Validation.Operator" value="8" type="Double" /><column name="account" property="Validation.Formula1" value="50" type="String" /><column name="account" property="Validation.AlertStyle" value="1" type="Double" /><column name="account" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="account" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="account" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="account" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="account" property="Validation.ShowInput" value="True" type="Boolean" /><column name="account" property="Validation.ShowError" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="Address" value="$L$4" type="String" /><column name="code1" property="NumberFormat" value="General" type="String" /><column name="code1" property="Validation.Type" value="6" type="Double" /><column name="code1" property="Validation.Operator" value="8" type="Double" /><column name="code1" property="Validation.Formula1" value="50" type="String" /><column name="code1" property="Validation.AlertStyle" value="1" type="Double" /><column name="code1" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code1" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code1" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code1" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code1" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code1" property="Validation.ShowError" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="Address" value="$M$4" type="String" /><column name="code2" property="NumberFormat" value="General" type="String" /><column name="code2" property="Validation.Type" value="6" type="Double" /><column name="code2" property="Validation.Operator" value="8" type="Double" /><column name="code2" property="Validation.Formula1" value="50" type="String" /><column name="code2" property="Validation.AlertStyle" value="1" type="Double" /><column name="code2" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code2" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code2" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code2" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code2" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code2" property="Validation.ShowError" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="Address" value="$N$4" type="String" /><column name="data_key" property="NumberFormat" value="General" type="String" /><column name="data_key" property="Validation.Type" value="6" type="Double" /><column name="data_key" property="Validation.Operator" value="8" type="Double" /><column name="data_key" property="Validation.Formula1" value="100" type="String" /><column name="data_key" property="Validation.AlertStyle" value="1" type="Double" /><column name="data_key" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data_key" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data_key" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data_key" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(100) datatype." type="String" /><column name="data_key" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data_key" property="Validation.ShowError" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="Address" value="$O$4" type="String" /><column name="data_index" property="NumberFormat" value="#,##0;[Red]-#,##0;" type="String" /><column name="data_index" property="Validation.Type" value="1" type="Double" /><column name="data_index" property="Validation.Operator" value="1" type="Double" /><column name="data_index" property="Validation.Formula1" value="-2147483648" type="String" /><column name="data_index" property="Validation.Formula2" value="2147483647" type="String" /><column name="data_index" property="Validation.AlertStyle" value="1" type="Double" /><column name="data_index" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data_index" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data_index" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data_index" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="data_index" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data_index" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$P$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$Q$4" type="String" /><column name="name" property="ColumnWidth" value="23.14" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="Address" value="$R$4" type="String" /><column name="data00" property="ColumnWidth" value="9.57" type="Double" /><column name="data00" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data00" property="Validation.Type" value="2" type="Double" /><column name="data00" property="Validation.Operator" value="4" type="Double" /><column name="data00" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data00" property="Validation.AlertStyle" value="1" type="Double" /><column name="data00" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data00" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data00" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data00" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data00" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data00" property="Validation.ShowError" value="True" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="Address" value="$S$4" type="String" /><column name="data01" property="ColumnWidth" value="8.57" type="Double" /><column name="data01" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data01" property="Validation.Type" value="2" type="Double" /><column name="data01" property="Validation.Operator" value="4" type="Double" /><column name="data01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data01" property="Validation.AlertStyle" value="1" type="Double" /><column name="data01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data01" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data01" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data01" property="Validation.ShowError" value="True" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="Address" value="$T$4" type="String" /><column name="data02" property="ColumnWidth" value="8.57" type="Double" /><column name="data02" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data02" property="Validation.Type" value="2" type="Double" /><column name="data02" property="Validation.Operator" value="4" type="Double" /><column name="data02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data02" property="Validation.AlertStyle" value="1" type="Double" /><column name="data02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data02" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data02" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data02" property="Validation.ShowError" value="True" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="Address" value="$U$4" type="String" /><column name="data03" property="ColumnWidth" value="8.57" type="Double" /><column name="data03" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data03" property="Validation.Type" value="2" type="Double" /><column name="data03" property="Validation.Operator" value="4" type="Double" /><column name="data03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data03" property="Validation.AlertStyle" value="1" type="Double" /><column name="data03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data03" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data03" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data03" property="Validation.ShowError" value="True" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="Address" value="$V$4" type="String" /><column name="data04" property="ColumnWidth" value="8.57" type="Double" /><column name="data04" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data04" property="Validation.Type" value="2" type="Double" /><column name="data04" property="Validation.Operator" value="4" type="Double" /><column name="data04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data04" property="Validation.AlertStyle" value="1" type="Double" /><column name="data04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data04" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data04" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data04" property="Validation.ShowError" value="True" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="Address" value="$W$4" type="String" /><column name="data05" property="ColumnWidth" value="8.57" type="Double" /><column name="data05" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data05" property="Validation.Type" value="2" type="Double" /><column name="data05" property="Validation.Operator" value="4" type="Double" /><column name="data05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data05" property="Validation.AlertStyle" value="1" type="Double" /><column name="data05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data05" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data05" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data05" property="Validation.ShowError" value="True" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="Address" value="$X$4" type="String" /><column name="data06" property="ColumnWidth" value="8.57" type="Double" /><column name="data06" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data06" property="Validation.Type" value="2" type="Double" /><column name="data06" property="Validation.Operator" value="4" type="Double" /><column name="data06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data06" property="Validation.AlertStyle" value="1" type="Double" /><column name="data06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data06" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data06" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data06" property="Validation.ShowError" value="True" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="Address" value="$Y$4" type="String" /><column name="data07" property="ColumnWidth" value="8.57" type="Double" /><column name="data07" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data07" property="Validation.Type" value="2" type="Double" /><column name="data07" property="Validation.Operator" value="4" type="Double" /><column name="data07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data07" property="Validation.AlertStyle" value="1" type="Double" /><column name="data07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data07" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data07" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data07" property="Validation.ShowError" value="True" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="Address" value="$Z$4" type="String" /><column name="data08" property="ColumnWidth" value="8.57" type="Double" /><column name="data08" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data08" property="Validation.Type" value="2" type="Double" /><column name="data08" property="Validation.Operator" value="4" type="Double" /><column name="data08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data08" property="Validation.AlertStyle" value="1" type="Double" /><column name="data08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data08" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data08" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data08" property="Validation.ShowError" value="True" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="Address" value="$AA$4" type="String" /><column name="data09" property="ColumnWidth" value="8.57" type="Double" /><column name="data09" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data09" property="Validation.Type" value="2" type="Double" /><column name="data09" property="Validation.Operator" value="4" type="Double" /><column name="data09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data09" property="Validation.AlertStyle" value="1" type="Double" /><column name="data09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data09" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data09" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data09" property="Validation.ShowError" value="True" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="Address" value="$AB$4" type="String" /><column name="data10" property="ColumnWidth" value="8.57" type="Double" /><column name="data10" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data10" property="Validation.Type" value="2" type="Double" /><column name="data10" property="Validation.Operator" value="4" type="Double" /><column name="data10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data10" property="Validation.AlertStyle" value="1" type="Double" /><column name="data10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data10" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data10" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data10" property="Validation.ShowError" value="True" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="Address" value="$AC$4" type="String" /><column name="data11" property="ColumnWidth" value="8.57" type="Double" /><column name="data11" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data11" property="Validation.Type" value="2" type="Double" /><column name="data11" property="Validation.Operator" value="4" type="Double" /><column name="data11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data11" property="Validation.AlertStyle" value="1" type="Double" /><column name="data11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data11" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data11" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data11" property="Validation.ShowError" value="True" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="Address" value="$AD$4" type="String" /><column name="data12" property="ColumnWidth" value="8.57" type="Double" /><column name="data12" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 ;" type="String" /><column name="data12" property="Validation.Type" value="2" type="Double" /><column name="data12" property="Validation.Operator" value="4" type="Double" /><column name="data12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data12" property="Validation.AlertStyle" value="1" type="Double" /><column name="data12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data12" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="data12" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="data12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data12" property="Validation.ShowError" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$AD$92" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$F4=-3" type="String" /><column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$4:$AD$92" type="String" /><column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Priority" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Formula1" value="=$F4=-2" type="String" /><column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$4:$AD$92" type="String" /><column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(3).Priority" value="3" type="Double" /><column name="_RowNum" property="FormatConditions(3).Formula1" value="=$F4=-1" type="String" /><column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299904" type="Double" /><column name="_RowNum" property="FormatConditions(4).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesTo.Address" value="$B$4:$AD$92" type="String" /><column name="_RowNum" property="FormatConditions(4).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(4).Priority" value="4" type="Double" /><column name="_RowNum" property="FormatConditions(4).Formula1" value="=$G4=1" type="String" /><column name="_RowNum" property="FormatConditions(4).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(4).Interior.Color" value="6773025" type="Double" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="All columns"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Report columns"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All reports"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view><view name="Revenue"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="AutoFilter.Criteria1" value="=1" type="String" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view><view name="Expenses"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="AutoFilter.Criteria1" value="=2" type="String" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view><view name="Margin Profit"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="AutoFilter.Criteria1" value="=3" type="String" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view><view name="Profit &amp; Losses"><column name="" property="ListObjectName" value="export" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_key" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="AutoFilter.Criteria1" value="=4" type="String" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's03', N'usp_request', N'<table name="s03.usp_request"><columnFormats><column name="" property="ListObjectName" value="Sheet1_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$4" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="row_index" property="Validation.Type" value="1" type="Double" /><column name="row_index" property="Validation.Operator" value="1" type="Double" /><column name="row_index" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_index" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_index" property="Validation.AlertStyle" value="2" type="Double" /><column name="row_index" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_index" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_index" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_index" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$D$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_format" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_format" property="Validation.Type" value="1" type="Double" /><column name="row_format" property="Validation.Operator" value="1" type="Double" /><column name="row_format" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_format" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_format" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowError" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="Address" value="$E$4" type="String" /><column name="comment" property="ColumnWidth" value="12.29" type="Double" /><column name="comment" property="NumberFormat" value="General" type="String" /><column name="comment" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="comment" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="comment" property="Validation.Type" value="6" type="Double" /><column name="comment" property="Validation.Operator" value="8" type="Double" /><column name="comment" property="Validation.Formula1" value="255" type="String" /><column name="comment" property="Validation.AlertStyle" value="1" type="Double" /><column name="comment" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="comment" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="comment" property="Validation.ShowInput" value="True" type="Boolean" /><column name="comment" property="Validation.ShowError" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$F$4" type="String" /><column name="account_id" property="ColumnWidth" value="12.14" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="Address" value="$G$4" type="String" /><column name="subaccount_id" property="ColumnWidth" value="15.43" type="Double" /><column name="subaccount_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$H$4" type="String" /><column name="product_id" property="ColumnWidth" value="12.14" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$I$4" type="String" /><column name="region_id" property="ColumnWidth" value="11" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="Address" value="$J$4" type="String" /><column name="total" property="FormulaR1C1" value="=[@01]+[@02]+[@03]+[@04]+[@05]+[@06]+[@07]+[@08]+[@09]+[@10]+[@11]+[@12]" type="String" /><column name="total" property="ColumnWidth" value="12.43" type="Double" /><column name="total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="total" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="total" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="total" property="Validation.Type" value="2" type="Double" /><column name="total" property="Validation.Operator" value="4" type="Double" /><column name="total" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="total" property="Validation.AlertStyle" value="2" type="Double" /><column name="total" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="total" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="total" property="Validation.ShowInput" value="True" type="Boolean" /><column name="total" property="Validation.ShowError" value="True" type="Boolean" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="Address" value="$K$4" type="String" /><column name="01" property="ColumnWidth" value="11.14" type="Double" /><column name="01" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="01" property="Validation.Type" value="2" type="Double" /><column name="01" property="Validation.Operator" value="4" type="Double" /><column name="01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="01" property="Validation.AlertStyle" value="1" type="Double" /><column name="01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="01" property="Validation.ShowError" value="True" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="Address" value="$L$4" type="String" /><column name="02" property="ColumnWidth" value="11.14" type="Double" /><column name="02" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="02" property="Validation.Type" value="2" type="Double" /><column name="02" property="Validation.Operator" value="4" type="Double" /><column name="02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="02" property="Validation.AlertStyle" value="1" type="Double" /><column name="02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="02" property="Validation.ShowError" value="True" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="Address" value="$M$4" type="String" /><column name="03" property="ColumnWidth" value="11.14" type="Double" /><column name="03" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="03" property="Validation.Type" value="2" type="Double" /><column name="03" property="Validation.Operator" value="4" type="Double" /><column name="03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="03" property="Validation.AlertStyle" value="1" type="Double" /><column name="03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="03" property="Validation.ShowError" value="True" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="Address" value="$N$4" type="String" /><column name="04" property="ColumnWidth" value="11.14" type="Double" /><column name="04" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="04" property="Validation.Type" value="2" type="Double" /><column name="04" property="Validation.Operator" value="4" type="Double" /><column name="04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="04" property="Validation.AlertStyle" value="1" type="Double" /><column name="04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="04" property="Validation.ShowError" value="True" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="Address" value="$O$4" type="String" /><column name="05" property="ColumnWidth" value="11.14" type="Double" /><column name="05" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="05" property="Validation.Type" value="2" type="Double" /><column name="05" property="Validation.Operator" value="4" type="Double" /><column name="05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="05" property="Validation.AlertStyle" value="1" type="Double" /><column name="05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="05" property="Validation.ShowError" value="True" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="Address" value="$P$4" type="String" /><column name="06" property="ColumnWidth" value="11.14" type="Double" /><column name="06" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="06" property="Validation.Type" value="2" type="Double" /><column name="06" property="Validation.Operator" value="4" type="Double" /><column name="06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="06" property="Validation.AlertStyle" value="1" type="Double" /><column name="06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="06" property="Validation.ShowError" value="True" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="Address" value="$Q$4" type="String" /><column name="07" property="ColumnWidth" value="11.14" type="Double" /><column name="07" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="07" property="Validation.Type" value="2" type="Double" /><column name="07" property="Validation.Operator" value="4" type="Double" /><column name="07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="07" property="Validation.AlertStyle" value="1" type="Double" /><column name="07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="07" property="Validation.ShowError" value="True" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="Address" value="$R$4" type="String" /><column name="08" property="ColumnWidth" value="11.14" type="Double" /><column name="08" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="08" property="Validation.Type" value="2" type="Double" /><column name="08" property="Validation.Operator" value="4" type="Double" /><column name="08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="08" property="Validation.AlertStyle" value="1" type="Double" /><column name="08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="08" property="Validation.ShowError" value="True" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="Address" value="$S$4" type="String" /><column name="09" property="ColumnWidth" value="11.14" type="Double" /><column name="09" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="09" property="Validation.Type" value="2" type="Double" /><column name="09" property="Validation.Operator" value="4" type="Double" /><column name="09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="09" property="Validation.AlertStyle" value="1" type="Double" /><column name="09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="09" property="Validation.ShowError" value="True" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="Address" value="$T$4" type="String" /><column name="10" property="ColumnWidth" value="11.14" type="Double" /><column name="10" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="10" property="Validation.Type" value="2" type="Double" /><column name="10" property="Validation.Operator" value="4" type="Double" /><column name="10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="10" property="Validation.AlertStyle" value="1" type="Double" /><column name="10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="10" property="Validation.ShowError" value="True" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="Address" value="$U$4" type="String" /><column name="11" property="ColumnWidth" value="11.14" type="Double" /><column name="11" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="11" property="Validation.Type" value="2" type="Double" /><column name="11" property="Validation.Operator" value="4" type="Double" /><column name="11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="11" property="Validation.AlertStyle" value="1" type="Double" /><column name="11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="11" property="Validation.ShowError" value="True" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="Address" value="$V$4" type="String" /><column name="12" property="ColumnWidth" value="11.14" type="Double" /><column name="12" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="12" property="Validation.Type" value="2" type="Double" /><column name="12" property="Validation.Operator" value="4" type="Double" /><column name="12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="12" property="Validation.AlertStyle" value="1" type="Double" /><column name="12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="12" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$W$4" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="row_formulas" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="Address" value="$X$4" type="String" /><column name="row_comments" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$X$23" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="6773025" type="Double" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="users" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All columns"><column name="" property="ListObjectName" value="users" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
GO

INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_report', NULL, N'ContextMenu', N's03', N'xl_details_report_cell_data', N'PROCEDURE', NULL, NULL, 1, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"formula":"row_format=1","format":"background-color: rgb(247,247,247);font-weight: 500;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'row_comments', N'KeepComments', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_data', N'category_id', N'ParameterValues', N's03', N'category_id', N'CODE', N'EXEC s03.xl_list_member_id 3, 1', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_data', N'entity_id', N'ParameterValues', N's03', N'entity_id', N'CODE', N'EXEC s03.xl_list_member_id 4, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_data', N'time_id', N'ParameterValues', N's03', N'time_id', N'CODE', N'EXEC s03.xl_list_member_id 2, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_report', N'category_id', N'ParameterValues', N's03', N'category_id', N'CODE', N'EXEC s03.xl_list_member_id 3, 1', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_report', N'time_id', N'ParameterValues', N's03', N'time_id', N'CODE', N'EXEC s03.xl_list_member_id 2, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'category_id', N'ParameterValues', N's03', N'category_id', N'CODE', N'EXEC s03.xl_list_member_id 3, 1', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'entity_id', N'ParameterValues', N's03', N'entity_id', N'CODE', N'EXEC s03.xl_list_member_id 4, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'time_id', N'ParameterValues', N's03', N'time_id', N'CODE', N'EXEC s03.xl_list_member_id 2, 1', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'account_id', N'ValidationList', N's03', N'account_id', N'CODE', N'EXEC s03.xl_list_member_id 1, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'product_id', N'ValidationList', N's03', N'product_id', N'CODE', N'EXEC s03.xl_list_member_id 6, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'region_id', N'ValidationList', N's03', N'region_id', N'CODE', N'EXEC s03.xl_list_member_id 5, 1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's03', N'usp_request', N'subaccount_id', N'ValidationList', N's03', N'subaccount_id', N'CODE', N'EXEC s03.xl_list_member_id 7, 1', NULL, NULL, NULL);
GO

INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'Sample 03 - Budgeting.xlsx', N'https://www.savetodb.com/downloads/v10/sample03-user1.xlsx', N'members=s03.members,(Default),False,$B$3,,{"Parameters":{"dimension_id":7},"ListObjectName":"members"}
request=s03.usp_request,(Default),False,$B$3,,{"Parameters":{"category_id":1,"time_id":5,"entity_id":11,"rows":20},"ListObjectName":"request"}
data=s03.usp_data,(Default),False,$B$3,,{"Parameters":{"category_id":1,"time_id":5,"entity_id":null},"ListObjectName":"data"}
export=s03.usp_report,(Default),False,$B$3,,{"Parameters":{"category_id":1,"time_id":5},"ListObjectName":"export"}', N's03');
GO

print 'Application installed';
